#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
test_ukmdb_itop
----------------------------------

Tests for `ukmdb_itop` module.
"""

from unittest import TestCase

import ukmdb_itop
from ukmdb_itop import itop


class TestUkmdb_itop(TestCase):

    @classmethod
    def setup_class(cls):
        pass

    def test_something(self):
        pass

    def test_ver(self):
        self.assertEqual(itop.get_mod_version(),
                         ukmdb_itop.__version__)

    @classmethod
    def teardown_class(cls):
        pass



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# pylint: disable=C0330,C0103
"""UKMDB Worker.

Usage: ukm_itop [--help] [--debug ...]

Options:
  -d --debug               Show debug information (maybe multiple).

  ukm_itop (-h | --help)
  ukm_itop --version

"""

from __future__ import absolute_import
import logging
from pprint import pformat
from celery import Celery
from docopt import docopt
from ukmdb_worker.base import set_debug_level
from ukmdb_worker import __version__
from ukmdb_worker import queues
from ukmdb_settings import settings


ukmdb_log = logging.getLogger("ukmdb")


app = Celery('worker',
             broker=settings.AMQP_BROKER_URL,
             )

queues.setup(app)

# app.conf.update(
#     CELERY_ROUTES={
#         'ukmdb_graph.worker.add_object': {
#             'queue': 'ukmdb_graph01',
#             'routing_key': '#',
#         },
#     },
# )
#


@app.task(serializer='json',
          name='worker.add_object',
          queue='ukmdb_itop01',
          exchange='ukmdb_all_in',
          routing_key='#',
          bind=True
          )
def add_object(self, msg):
    ukmdb_log.debug("-------> self.request: '%s'", pformat(self.request))
    ukmdb_log.debug("itop # add_object: '%s'", str(msg))


def main():
    arguments = docopt(__doc__, options_first=True, version=__version__)
    set_debug_level(ukmdb_log, arguments)

    ukmdb_log.debug(u'program start')
    app.start()

    exit("See 'ukm_itop --help'.")



#!/usr/bin/env python
# -*- coding: utf-8 -*-
# pylint: disable=C0103


try:
    from setuptools import setup
except ImportError:
    from distutils.core import setup    # pylint: disable=E0401,E0611


with open('README.rst') as readme_file:
    readme = readme_file.read()

with open('HISTORY.rst') as history_file:
    history = history_file.read()

requirements = [
]

test_requirements = [
]

setup(
    name='ukmdb_itop',
    version='0.0.3',
    description="UKMDB itop adapter.",
    long_description=readme + '\n\n' + history,
    author="Markus Leist",
    author_email='markus@lei.st',
    url='https://github.com/mleist/ukmdb_itop',
    packages=[
        'ukmdb_itop',
    ],
    package_dir={'ukmdb_itop':
                 'ukmdb_itop'},
    include_package_data=True,
    install_requires=requirements,
    license="GPLv3",
    zip_safe=False,
    keywords='ukmdb itop',
    entry_points={
        'console_scripts': [
            'ukm_itop = ukmdb_itop.worker:main',
        ],
    },
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: System Administrators',
        'Intended Audience :: Information Technology',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Natural Language :: English',
        'Programming Language :: Python',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: System :: Monitoring',
        'Topic :: System :: Logging',
        'Topic :: Internet :: Log Analysis',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    test_suite='tests',
    tests_require=test_requirements
)
